@@ -336,29 +336,29 @@ class Interpreter:
             expr = expr.Left
         val = var.Value
         if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-            raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}', ind.Token.Location, self.filename)    
+            raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}).', idx.Token.Location, self.filename)    
         for ind in vind:
             if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}', ind.Token.Location, self.filename)
+                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}).', ind.Token.Location, self.filename)
             if ind.ExprType == types.ExprTypes.NewArrayIndex:
                 raise exceptions.RuntimeError('Append not supported on right hand side.', ind.Token.Location, self.filename)
             i = self.InterpretExpression(ind, scope)
             if val.Type == types.VariableTypes.Record:
                 if i.Value not in val.Value:
-                    raise exceptions.RuntimeError(f'Index ({i.Value}) not found.', ind.Token.Location, self.filename)
+                    raise exceptions.RuntimeError(f'Index ({i.Value}) not found. ({var.Name}).', ind.Token.Location, self.filename)
             elif val.Type == types.VariableTypes.Array or val.Type == types.VariableTypes.String:
                 if i.Type != types.VariableTypes.Int:
-                    raise exceptions.RuntimeError(f'Invalid index type ({i.Type}), Int index type required.', ind.Token.Location, self.filename)
+                    raise exceptions.RuntimeError(f'Invalid index type ({i.Type}), Int index type required. ({var.Name}).', ind.Token.Location, self.filename)
                 if i.Value < 0 or i.Value >= len(val.Value):
-                    raise exceptions.RuntimeError(f'Index ({i.Value}) is out of range.', ind.Token.Location, self.filename)
+                    raise exceptions.RuntimeError(f'Index ({i.Value}) is out of range. ({var.Name}).', ind.Token.Location, self.filename)
             else:
-                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}', ind.Token.Location, self.filename)
+                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}).', ind.Token.Location, self.filename)
             if val.Type == types.VariableTypes.String:
                 val = value_item.ValueItem().SetFromMacal(val.Token, val.Type, val.Value[i.Value])
             else:
                 val = val.Value[i.Value]
         if expr.Right is not None and expr.Right.ExprType == types.ExprTypes.NewArrayIndex:
-            raise exceptions.RuntimeError(f'Append not supported on right hand side', ind.Token.Location, self.filename)
+            raise exceptions.RuntimeError(f'Append not supported. ({var.Name}).', expr.Right.Token.Location, self.filename)
         return val
 
 
