@@ -14,4 +14,7 @@ class SourceLocation:
         return f"SourceLocation(line={self.Line}, column={self.Column})"
 
     def __str__(self):
-        return f"@({self.Line}, {self.Column})"
\ No newline at end of file
+        return f"@({self.Line}, {self.Column})"
+
+def nullLoc():
+    return SourceLocation(-1,-1)
\ No newline at end of file
